`simData_00000.bp` is the output created by PIConGPU, written as a BP4 file.
I have deleted all but the metadata, meaning that reading any array data with ADIOS2 will fail.
This reproducer uses the structure of that output to recreate the setup that makes the Cray-MPI-based SST streaming setup fail on Crusher.

Steps:

1. In `submit.sh`, replace the account name, as well as the `source ~/crusher_env/env.sh` line with the path to your environment.
   I have loaded the following modules and additionally installed ADIOS2 v2.9.0-rc1 manually.

   ```
   > module list
   Currently Loaded Modules:
   1) craype-x86-trento                       6) cray-pmi/6.1.3    11) cray-libsci/22.06.1.3    16) rocm/5.1.0            21) zlib/1.2.11
   2) libfabric/1.15.0.0                      7) tmux/3.2a         12) PrgEnv-cray/8.2.0        17) cray-mpich/8.1.21     22) git/2.35.1
   3) craype-network-ofi                      8) cce/14.0.2        13) xalt/1.3.0               18) cmake/3.21.3          23) libpng/1.6.37
   4) perftools-base/22.06.0                  9) craype/2.7.16     14) DefApps/default          19) boost/1.79.0-cxx17    24) freetype/2.11.0
   5) xpmem/2.4.4-2.3_11.2__gff0e1d9.shasta  10) cray-dsmml/0.2.2  15) craype-accel-amd-gfx90a  20) cray-python/3.9.12.1  25) gdb/10.2
   ```

2. Build the binaries by

   a) Loading an environment that has a recent ADIOS2 build
   b) `mkdir build; cd build; cmake ..; make -j 2; cd ..`

3. Submit the job by `sbatch submit.sh`

The job script emulates the way that PIConGPU uses ADIOS2 SST.
It launches 8 instances of `adios2_mock_stream` per compute node and 1 instance of `adios2_read_stream` per compute node on a total of 16 nodes.

* `adios2_mock_stream` emulates PIConGPU's SST output, by running at a total of 128 MPI ranks.
  It evaluates the structure of the sample dataset `simData_00000.bp`, which contains 48 variables with 128*8 written blocks each (i.e. it has been created by PIConGPU running on 128 nodes).
  Each MPI rank *i* will recreate in the output stream each variable that it finds in the sample, and will create a chunk that corresponds to the sample chunk *i*, filled with zeroes.
  Additionally, rank 0 will define a 2D char variable called `/rankTable`. It contains meta information loaded by every reader rank.
  This replicates a stream as if it were created by PIConGPU.
  An artificial last step is added to trigger the QueueFullPolicy.
* `adios2_read_stream` will now attempt reading that stream by loading from each variable the blocks that were produced on the same node.
  This works without an issue.

  There are two further things that will fail:

  1. All datasets named `.*particlePatches.*` are loaded only by rank 0.
     They are very small, but each writer rank contributes a low count of integers to them.
     This communication pattern (n->1) will cause a hangup at 16 nodes.

  2. In order to observe the second issue, you must remove the first issue by removing the `#define RANKTABLE_ISSUE` line in `adios2_read_stream.cpp`.
     The second issue occurs at 128 nodes, so the `submit.sh` script must be adapted (changing 16 to 128 at two places).
     The second issue is triggered by each reader rank loading the `/rankTable` dataset.
     Again, this dataset is very small, but the system does not support the 1->m communication pattern.
