#!/usr/bin/env bash
#SBATCH --account=csc380
#SBATCH --time=00:10:00
# Sets batch job's name
#SBATCH --job-name=run_16_nodes
#SBATCH --nodes=16
#SBATCH --gpu-bind=closest
#SBATCH --chdir=./run
# The following two parameters are needed to avoid batch system hangups
# when trying to run two sub-jobs asynchronously.
#SBATCH -S 0
#SBATCH --exclusive

#SBATCH -o stdout
#SBATCH -e stderr

nodes=16

echo 'Start job with $nodes nodes. Required are $nodes nodes.'

source ~/crusher_env/env.sh

export SstVerbose=30

export MPICH_OFI_NIC_POLICY=NUMA # The default


export MPICH_OFI_CXI_PID_BASE=0
# Corresponds to the cores 0, 8, 16, 24, 32, 40, 48, 56
# (first core in each L3 cache group)
mask="0x101010101010101"

srun                                              \
    --ntasks $nodes                               \
    --nodes $nodes                                \
    $exclude_nodes                                \
    --ntasks-per-node=1                           \
    --gpus-per-node=0                             \
    --cpus-per-task=7                             \
    --cpu-bind=verbose,mask_cpu:$mask             \
    ../build/adios2_read_stream simData.sst       \
    > reader.out 2> reader.err                    &

sleep 1

export MPICH_OFI_CXI_PID_BASE=$((MPICH_OFI_CXI_PID_BASE+1))
# Corresponds to cores 1-8 (exclude first core) in each L3 cache group
mask=0xfe,0xfe00,0xfe0000,0xfe000000,0xfe00000000,0xfe0000000000,0xfe000000000000,0xfe00000000000000

srun                                                              \
    --overlap                                                     \
    --ntasks $((8*nodes))                                         \
    --nodes=$nodes                                                \
    $exclude_nodes                                                \
    --ntasks-per-node=8                                           \
    --gpus-per-node=8                                             \
    --cpus-per-task=7                                             \
    --cpu-bind=verbose,mask_cpu:$mask                             \
    -K1                                                           \
    ../build/adios2_mock_stream ../simData_00000.bp simData.sst  \
    > writer.out 2> writer.err                                    &

wait